\name{Divs0103}
\alias{Divs0103}
\docType{data}
\title{ UK House of Commons Division Lists, 2001-2003 }
\description{
  A list, with one element for each parliamentary division in the
  second New Labour term of office.  Not complete until that term of office
  ends!  The names of those voting aye and no, as they appear in Hansard but 
  with spelling and typographical errors corrected.
}
\usage{data(Divs0103)}
\format{
	A list, each component of which corresponds to one House of Commons 
	division.   Each division is 
	itself a list, with three components: 
	\describe{
		\item{
		\code{url}}{the URL for the Hansard page containing 
		the division list.
		Character.}
		\item{
		\code{ayes}}{Character vector, the names of those voting AYE.
		}
		\item{
		\code{noes}}{Character vector, the names of those voting NO.
		}
	}
}
\details{
  Some corrections have been made (e.g., spellings) to the original 
  Hansard lists.
}
\source{
  Hansard online.  The URL is supplied for each division.
}
\references{
  Firth, D and Spirling, A (2003) Divisions of the United Kingdom House of 
  Commons, from 1992 to 2003 and beyond.  Submitted for publication.  At
  \url{http://www.stats.ox.ac.uk/~firth/tapiR/}.
}
\examples{
data(Divs0103)
}
\keyword{datasets}
\eof
\name{MPnames0103}
\alias{MPnames0103}
\docType{data}
\title{ Members of the House of Commons, 2001-2003 }
\description{
  A data frame containing MP name, abbreviated constituency 
  name where used, and party affiliation.
}
\usage{data(MPnames0103)}
\format{
  A data frame with 653 observations on the following 3 variables.
  \describe{
    \item{\code{MPname}}{a character vector, names of MPs}
    \item{\code{seatname}}{a character vector, abbreviated constituency name where used}
    \item{\code{party}}{a factor with levels \code{Con} \code{DUP} \code{Ind} \code{IndCon} \code{LD} \code{Lab} \code{PC} \code{SDLP} \code{SNP} \code{UU}}
  }
}
\references{
  Firth, D and Spirling, A (2003) Divisions of the United Kingdom House of 
  Commons, from 1992 to 2003 and beyond.  Submitted for publication.  At
  \url{http://www.stats.ox.ac.uk/~firth/tapiR/}.
}
\examples{
data(MPnames0103)
}
\keyword{datasets}
\eof
\name{Votes0103}
\alias{Votes0103}
\docType{data}
\title{ Voting on House of Commons Divisions between June 2001 and July 2003}
\description{
  A data frame
}
\usage{data(Votes0103)}
\format{
  The votes are organized as a data frame data frame with 653 
  observations (MPs) on the following 658 
  variables (657 of which are divisions of the House).
  \describe{
    \item{\code{party}}{a factor with levels \code{Con} \code{DUP} \code{Ind} \code{IndCon} \code{LD} \code{Lab} \code{PC} \code{SDLP} \code{SNP} \code{UU}}
    \item{\code{div001.010626}}{a factor with levels \code{-} \code{n} \code{y}}
    \item{...}{656 further such variables, ending with}
    \item{\code{div293.030716}}{a factor with levels \code{-} \code{n} \code{y}}
  }
}
\details{
  Some divisions have the additional factor level \code{b}, indicating 
  that one or more MPs voted both Aye and No.
}
\source{
  Derived, using \code{\link{get.divisions}}, from the online 
  pages of the official Parliamentary record \emph{Hansard}.
}
\note{
Corresponding data for the 1992-1997 and 1997-2001 parliaments can be found at 
\url{http://www.stats.ox.ac.uk/~firth/tapiR/}
}
\references{
  Firth, D and Spirling, A (2003) Divisions of the United Kingdom House of 
  Commons, from 1992 to 2003 and beyond.  Submitted for publication.  At
  \url{http://www.stats.ox.ac.uk/~firth/tapiR/}.
}
\examples{
data(Votes0103)
}
\keyword{datasets}
\eof
\name{collect.MPnames}
\alias{collect.MPnames}
\title{ Gather all MP Names from a Set of Division Lists }
\description{
  Constructs a comprehensive dataset of all MP names found in a 
  set of House of Commons division lists, in alphabetical order and
  with duplicates removed.
}
\usage{
collect.MPnames(divs, verbose = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{divs}{ A list, each component representng one House of Commons 
  division.  For the format see \code{\link{Divs0103}}.}
  \item{verbose}{ Logical.  If \code{TRUE}, progress is reported. }
}
\value{
  A data frame with two columns, \code{MPname} and \code{seatname}.
}
\references{
  Firth, D and Spirling, A (2003) Divisions of the United Kingdom House of 
  Commons, from 1992 to 2003 and beyond.  Submitted for publication.  At
  \url{http://www.stats.ox.ac.uk/~firth/tapiR/}.
}
\author{ David Firth }
\notes{
This is a utility functon, for use in the construction of a 
dataset such as \code{\link{MPnames0103}}.  
}
\seealso{ \code{\link{uniquify.MPnames}} }
\examples{
data(Divs0103)
##  Collect all names from the first two divisions in June 2001:
collect.MPnames(Divs0103[1:2])
}
\keyword{ manip }
\eof
\name{find.divisions}
\alias{find.divisions}
\title{ Locate division lists for the UK House of Commons }
\description{
  Searches the online parliamentary record, Hansard, for the URLs of pages 
  containing division lists.  For each division found, returns the URL 
  and Hansard's textual tag indicating the topic under debate.
}
\usage{
find.divisions(session, dates)
}
\arguments{
  \item{session}{ A 4-digit identifier for the parliamentary session
  to be searched, e.g., 0203 for the year 2002-3. }
  \item{dates}{ A numeric vector of dates in the format yymmdd.  Ranges
  may be specified, e.g., 030515:030716 for the period May 15
  to July 16 2003. }
}
\details{
  Requires internet access.
}
\value{
	A two-column character matrix.  
	Columns are \code{debate} and \code{URL}.  
	Rows are indexed by division identifiers.
}
\references{ ~put references to the literature/web site here ~ }
\author{ David Firth }
\seealso{ \code{\link{get.divisions}} }
\examples{
\dontrun{
myURLs <- find.divisions(0203, 030715:030716)
myDivs <- get.divisions(myURLs)
}}
\keyword{ IO }
\eof
\name{get.divisions}
\alias{get.divisions}
\title{Fetch House of Commons Division Lists from a File or from the Web}
\description{
  Visits a list of URLs and extracts division lists in the standard format
  used by \emph{Hansard} online.
}
\usage{
get.divisions(URLs)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{URLs}{ A character vector of URLs (uniform resource 
     locators).  These may be local files or \emph{Hansard} web pages. }
}
\details{
  A single URL may point to a file or page containing 
  more than one division list.
}
\value{
  A list, with one component for each division list found.  
  For the format see \code{\link{Divs0103}}.
}
\references{
  Firth, D and Spirling, A (2003) Divisions of the United Kingdom House of 
  Commons, from 1992 to 2003 and beyond.  Submitted for publication.  At
  \url{http://www.stats.ox.ac.uk/~firth/tapiR/}.
}
\author{ David Firth }

\examples{
\dontrun{
##  Get the first two divisions for the session starting in June 2001:
myURLs <- c(
"http://www.parliament.the-stationery-office.co.uk/pa/cm200102/cmhansrd/vo010626/debtext/10626-30.htm", 
"http://www.parliament.the-stationery-office.co.uk/pa/cm200102/cmhansrd/vo010627/debtext/10627-29.htm")
first.two.divs <- get.divisions(myURLs)
}
}
\keyword{ IO }
\keyword{ manip }
\eof
\name{make.votesheet}
\alias{make.votesheet}
\title{ Make a Rectangular Dataset from House of Commons Division Data }
\description{
  Takes one or more House of Commons division lists and records the votes
  in a data frame with one row for each MP and one column for each division.
}
\usage{
make.votesheet(divs, MPnames, verbose = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{divs}{ A list, with one component for each division.  Each division
  	is itself a list, with three components \code{url}, 
  	\code{ayes} and \code{noes}. }
  \item{MPnames}{ A data frame of unique MP names, seatnames and parties. }
  \item{verbose}{ Logical.  If \code{TRUE}, progress is reported 
  	on standard output. }
}
\value{
  A data frame.  See \code{\link{Votes0103}} for the format.
}
\references{
  Firth, D and Spirling, A (2003) Divisions of the United Kingdom House of 
  Commons, from 1992 to 2003 and beyond.  Submitted for publication.  At
  \url{http://www.stats.ox.ac.uk/~firth/tapiR/}.
}
\author{ David Firth }
\seealso{ \code{\link{write.votesheet}} }
\examples{
data(Divs0103)
data(MPnames0103)
##  Do the first three divisions in June 2001:
make.votesheet(Divs0103[1:3], MPnames0103)
}
\keyword{ manip }
\eof
\name{namerules.9203}
\alias{namerules.9203}
\title{ Transform MP Names to a Unique Form }
\description{
  A function to implement rules for naming MPs and
  their constituencies unambiguously
}
\usage{
namerules.9203(MPnames, seatnames)
}
\arguments{
  \item{MPnames}{ Character vector }
  \item{seatnames}{ Character vector }
}
\value{
  A list, with components
  \item{MPnames }{A character vector}
  \item{seatnames }{A character vector}
  ...
}
\references{
  Firth, D and Spirling, A (2003) Divisions of the United Kingdom House of 
  Commons, from 1992 to 2003 and beyond.  Submitted for publication.  At
  \url{http://www.stats.ox.ac.uk/~firth/tapiR/}.
}
\author{ David Firth }
\note{ These are the rules that were used in constructing House of
  Commons voting datasets for the period 1992 to 2003.  They may need
  amendment for divisions recorded after May 2003, for example if a new
  member joins the House or if an MP becomes known by a new name. }
\examples{
namerules.9203(c("Bloggs, Joe", "Boswell, Timothy"), c("Deeside", "NA"))
}
\keyword{ manip }

\eof
\name{partyhues}
\alias{partyhues}
\title{ Convert Major Party Names to Colours }
\description{
  Converts names of political parties into colours, for plotting
  purposes.  "Lab" becomes "red", "Con" becomes "blue", "LD" becomes
  "yellow", others are "black".
}
\usage{
partyhues(vec)
}
\arguments{
  \item{vec}{ A vector of party names }
}
\value{
  A character vector of colours.
}
\author{ David Firth }
\examples{
partyhues(c("LD", "SNP", "LD", "Con", "Lab"))
}
\keyword{ manip }

\eof
\name{standard.divname}
\alias{standard.divname}
\title{ Convert Hansard's Online Division Identifiers to a Standard Format }
\description{
  \emph{Hansard}, the official Parliamentary record, has a system of 
  identifiers for divisions of the House.  This function converts
  the Hansard identifier to one in the format \code{div***.yymmdd},
  where \code{***} is the 3-digit division number and \code{yymmdd}
  the date on which the division took place.
}
\usage{
standard.divname(div.id)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{div.id}{ a character vector containing one or more division 
  identifiers as used in the online \emph{Hansard} }
}
\value{
  A character vector.
}
\author{ David Firth }
\references{
  Firth, D and Spirling, A (2003) Divisions of the United Kingdom House of 
  Commons, from 1992 to 2003 and beyond.  Submitted for publication.  At
  \url{http://www.stats.ox.ac.uk/~firth/tapiR/}.
}
\examples{
##  For division number 1 on 26 June 2001:
standard.divname("10626-30_div1")
}
\keyword{ manip }
\eof
\name{uniquify.MPnames}
\alias{uniquify.MPnames}
\title{ Put MP Names into a Unique Form }
\description{
  \emph{Hansard}, the official Parliamentary record, frequently 
  uses different forms for the name of the same MP.  This function
  applies both general rules, and \emph{ad hominem} rules contained 
  in the function supplied as argument \code{namerules}, to convert
  all names to a pre-determined form.
}
\usage{
uniquify.MPnames(ayes.or.noes, namerules = namerules.9203)
}
\arguments{
  \item{ayes.or.noes}{ A character vector of MP names, typically 
  either Ayes or Noes from a \emph{Hansard} division list.  }
  \item{namerules}{ A function implementing particularistic
  	rules by which certain names should be changed.  This function
  	takes two arguments, \code{MPnames} and \code{seatnames}, 
  	character vectors of the same length; it returns a 2-component list 
  	with components named \code{MPnames} and \code{seatnames}, these 
  	being the same vectors after modification by the rules. }
}
\value{
A character matrix, with one row for each element of \code{ayes.or.noes}.  
Two columns, \code{MPname} and \code{seatname}.
}
\author{ David Firth }
\notes{
  This function would not normally be called by the user
  of \code{\link{tapiR}}; 
  it is used internally by \code{\link{collect.MPnames}}
  and \code{\link{make.votesheet}}.
}
\examples{
uniquify.MPnames(c("Smith, Mr John (This Place)", 
"Jones, Dr Bill (Some Other Place)", "Spratt, Jack"))
}
\keyword{ manip }
\eof
\name{write.csv}
\alias{write.csv}
\title{ Write a Data Frame in  
	.csv Format }
\description{
  Writes a data frame in \emph{comma-separated values} format, either to
  a file or to standard output.
}
\usage{
write.csv(x, file = "")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{ a data frame }
  \item{file}{ a file name, usually ending in \code{.csv} }
}
\details{
  If no file name is supplied, the results appear on standard output.
}
\value{
  \code{invisible(NULL)}
}
\references{
  Firth, D and Spirling, A (2003) Divisions of the United Kingdom House of 
  Commons, from 1992 to 2003 and beyond.  Submitted for publication.  At
  \url{http://www.stats.ox.ac.uk/~firth/tapiR/}.
}
\author{ David Firth }
\note{ The inverse operation, to read in data from a \code{.csv} file, is 
	\code{mydata <- read.csv("myfile.csv", row.names = 1) } }

 ~Make other sections like Warning with \section{Warning }{....} ~ 
\seealso{ \code{\link{read.csv}} }
\examples{
data(MPnames0103)
write.csv(MPnames0103)
}
\keyword{ IO }
\keyword{ file }
\eof
\name{write.votesheet}
\alias{write.votesheet}
\title{Output House of Commons Voting Data Compactly}
\description{
  Writes out a data frame of House of Commons voting data, either 
  to a text file or to standard output.
}
\usage{
write.votesheet(x, file = NULL, keep.b = FALSE, 
	aye = "y", no = "n", novote = "-")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{A data frame of the kind made by 
  	\code{\link{make.votesheet}} }
  \item{file}{ An optional file name for the printed representation.
  	If \code{NULL}, printing is to standard output.}
  \item{keep.b}{ Should instances of \code{b} in the voting data,
  	meaning that an MP was recorded as having voted both Aye and No,
  	be retained in the output?  If \code{FALSE}, then \code{b} is
  	converted everywhere to \code{-}.}
  \item{aye}{ A one-character code for an Aye vote. }
  \item{no}{ A one-character code for a No vote. }
  \item{novote}{ A one-character code for neither Aye nor No 
      (i.e., a vote was not recorded) }
}
\value{
	\code{invisible(NULL)}
}
\references{
  Firth, D and Spirling, A (2003) Divisions of the United Kingdom House of 
  Commons, from 1992 to 2003 and beyond.  Submitted for publication.  At
  \url{http://www.stats.ox.ac.uk/~firth/tapiR/}.
}
\author{ David Firth }
\note{ Codes used as input to Keith Poole's OC (optimal classification) program are 
\code{aye = "1", no = "6", novote = "0"} }

\examples{
data(Votes0103)
write.votesheet(Votes0103[1:10, 1:10])
}
\keyword{ IO }
\keyword{ file }
\eof
